@@ -107,6 +107,7 @@ where
     where
         T: Float,
     {
+        check_partial_index(var_idx, self.n_vars(), self.unparse()?.as_str())?;
         let ops = DefaultOpsFactory::make();
 
         let d_i = partial_derivatives::partial_deepex(
@@ -130,6 +131,10 @@ where
     fn reduce_memory(&mut self) {
         self.deepex = None;
     }
+
+    fn n_vars(&self) -> usize {
+        self.n_unique_vars
+    }
 }
 
 /// The expression is displayed as a string created by [`unparse`](FlatEx::unparse).
@@ -234,6 +239,8 @@ where
     where
         T: Float,
     {
+        check_partial_index(var_idx, self.n_vars(), self.unparse()?.as_str())?;
+
         let ops = DefaultOpsFactory::make();
         let deep_buf = match self.deepex_buf {
             Some(d) => Ok(d),
@@ -259,6 +266,10 @@ where
     fn reduce_memory(&mut self) {
         self.deepex_buf = None;
     }
+
+    fn n_vars(&self) -> usize {
+        self.n_unique_vars
+    }
 }
 /// The expression is displayed as a string created by [`unparse`](OwnedFlatEx::unparse).
 impl<T, OF> Display for OwnedFlatEx<T, OF>
@@ -284,6 +295,8 @@ use crate::{
 #[cfg(test)]
 use smallvec::smallvec;
 
+use super::flat_details::check_partial_index;
+
 #[test]
 fn test_operate_unary() {
     let lstr = "x+y+x+z*(-y)+x+y+x+z*(-y)+x+y+x+z*(-y)+x+y+x+z*(-y)+x+y+x+z*(-y)+x+y+x+z*(-y)+x+y+x+z*(-y)+x+y+x+z*(-y)";
