@@ -47,6 +47,12 @@ pub fn is_numeric_regex<'a>(re: &Regex, text: &'a str) -> Option<&'a str> {
     }
 }
 
+fn next_char_boundary(text: &str, start_idx: usize) -> usize {
+    (1..text.len())
+        .find(|idx| text.is_char_boundary(start_idx + idx))
+        .expect("there has to be a char boundary somewhere")
+}
+
 /// Parses tokens of a text with regexes and returns them as a vector
 ///
 /// # Arguments
@@ -69,32 +75,32 @@ where
     T: Copy + FromStr + Debug,
     F: Fn(&'a str) -> Option<&'a str>,
 {
-    // Make sure that the text does not contain unicode characters
-    if text.chars().any(|c| !c.is_ascii()) {
-        return Err(ExError {
-            msg: "only ascii characters are supported".to_string(),
-        });
-    };
-
     // We sort operators inverse alphabetically such that log2 has higher priority than log (wlog :D).
     let mut ops_tmp = ops_in.iter().clone().collect::<SmallVec<[_; 64]>>();
     ops_tmp.sort_unstable_by(|o1, o2| o2.repr().partial_cmp(o1.repr()).unwrap());
     let ops = ops_tmp; // from now on const
 
     lazy_static! {
-        static ref RE_VAR_NAME: Regex = Regex::new(r"^[a-zA-Z_]+[a-zA-Z_0-9]*").unwrap();
+        static ref RE_VAR_NAME: Regex =
+            Regex::new(r"^[a-zA-Zα-ωΑ-Ω_]+[a-zA-Zα-ωΑ-Ω_0-9]*").unwrap();
     }
     lazy_static! {
-        static ref RE_VAR_NAME_EXACT: Regex = Regex::new(r"^[a-zA-Z_]+[a-zA-Z_0-9]*$").unwrap();
+        static ref RE_VAR_NAME_EXACT: Regex =
+            Regex::new(r"^[a-zA-Zα-ωΑ-Ω_]+[a-zA-Zα-ωΑ-Ω_0-9]*$").unwrap();
     }
 
-    let find_ops = |offset: usize| {
+    let find_ops = |byte_offset: usize| {
         ops.iter().find(|op| {
-            let range_end = offset + op.repr().chars().count();
-            if range_end > text.len() {
-                false
-            } else if op.repr() == &text[offset..range_end] {
-                if  !op.has_bin() && range_end < text.len() && RE_VAR_NAME_EXACT.is_match(&text[offset..range_end + 1]) {
+            let range_end = byte_offset + op.repr().len();
+            if let Some(maybe_op) = &text.get(byte_offset..range_end) {
+                if op.repr() != *maybe_op {
+                    false
+                } else if !op.has_bin()
+                    && range_end < text.len()
+                    && RE_VAR_NAME_EXACT.is_match(
+                        &text[byte_offset..range_end + next_char_boundary(&text, range_end)],
+                    )
+                {
                     false
                 } else {
                     true
@@ -105,44 +111,46 @@ where
         })
     };
     let mut res: SmallVec<[_; N_NODES_ON_STACK]> = SmallVec::new();
-    let mut cur_offset = 0usize;
-    for (i, c) in text.chars().enumerate() {
+    let mut cur_byte_offset = 0usize;
+    for (i, c) in text.char_indices() {
         if c == ' ' {
-            cur_offset += 1;
-        } else if i == cur_offset && cur_offset < text.len() {
-            let text_rest = &text[cur_offset..];
+            cur_byte_offset += 1;
+        } else if i == cur_byte_offset && cur_byte_offset < text.len() {
+            let text_rest = &text[cur_byte_offset..];
             let next_parsed_token = if c == '(' {
-                cur_offset += 1;
+                cur_byte_offset += 1;
                 ParsedToken::<T>::Paren(Paren::Open)
             } else if c == ')' {
-                cur_offset += 1;
+                cur_byte_offset += 1;
                 ParsedToken::<T>::Paren(Paren::Close)
             } else if c == '{' {
-                let n_count = text_rest.chars().take_while(|c| *c != '}').count();
+                let n_count = text_rest
+                    .chars()
+                    .take_while(|c| *c != '}')
+                    .map(|c| c.len_utf8())
+                    .sum();
                 let var_name = &text_rest[1..n_count];
                 let n_spaces = var_name.chars().filter(|c| *c == ' ').count();
                 // we need to subtract spaces from the offset, since they are added in the first if again.
-                cur_offset += n_count + 1 - n_spaces;
+                cur_byte_offset += n_count + 1 - n_spaces;
                 ParsedToken::<T>::Var(var_name)
             } else if let Some(num_str) = is_numeric(text_rest) {
-                let n_chars = num_str.chars().count();
-                cur_offset += n_chars;
-                ParsedToken::<T>::Num(num_str.parse::<T>().map_err(
-                    |e| ExError{
-                        msg: format!("could not parse '{}', {:?}", num_str, e)
-                    })?
-                )
-            } else if let Some(op) = find_ops(cur_offset) {
-                let n_chars = op.repr().chars().count();
-                cur_offset += n_chars;
+                let n_bytes = num_str.len();
+                cur_byte_offset += n_bytes;
+                ParsedToken::<T>::Num(num_str.parse::<T>().map_err(|e| ExError {
+                    msg: format!("could not parse '{}', {:?}", num_str, e),
+                })?)
+            } else if let Some(op) = find_ops(cur_byte_offset) {
+                let n_bytes = op.repr().len();
+                cur_byte_offset += n_bytes;
                 match op.constant() {
                     Some(constant) => ParsedToken::<T>::Num(constant),
                     None => ParsedToken::<T>::Op(**op),
                 }
             } else if let Some(var_str) = RE_VAR_NAME.find(text_rest) {
                 let var_str = var_str.as_str();
-                let n_chars = var_str.chars().count();
-                cur_offset += n_chars;
+                let n_bytes = var_str.len();
+                cur_byte_offset += n_bytes;
                 ParsedToken::<T>::Var(var_str)
             } else {
                 let msg = format!("don't know how to parse {}", text_rest);
@@ -211,12 +219,12 @@ fn make_pair_pre_conditions<'a, 'b, T: Copy + FromStr + Debug>() -> [PairPreCond
                 (ParsedToken::Op(op_l), ParsedToken::Op(op_r))
                     if !op_l.has_unary() && !op_r.has_unary() =>
                 {
-                    Err(ExError{
-                        msg:format!(
-                            "a binary operator cannot be next to the binary operator, violated by '{}' left of '{}'", 
-                            op_l.repr(), 
+                    Err(ExError {
+                        msg: format!(
+                            "a binary operator cannot be next to the binary operator, violated by '{}' left of '{}'",
+                            op_l.repr(),
                             op_r.repr()
-                        )
+                        ),
                     })
                 }
                 _ => Ok(()),
@@ -229,12 +237,12 @@ fn make_pair_pre_conditions<'a, 'b, T: Copy + FromStr + Debug>() -> [PairPreCond
                 (ParsedToken::Op(op_l), ParsedToken::Op(op_r))
                     if !op_l.has_bin() && !op_r.has_unary() =>
                 {
-                    Err(ExError{
-                        msg:format!(
-                            "a unary operator cannot be on the left of a binary one, violated by '{}' left of '{}'", 
-                            op_l.repr(), 
+                    Err(ExError {
+                        msg: format!(
+                            "a unary operator cannot be on the left of a binary one, violated by '{}' left of '{}'",
+                            op_l.repr(),
                             op_r.repr()
-                        )
+                        ),
                     })
                 }
                 _ => Ok(()),
@@ -397,9 +405,9 @@ fn test_preconditions() {
             x += i;
             let ops = DefaultOpsFactory::<f32>::make();
             let _elts = tokenize_and_analyze(text, &ops, is_numeric_text);
-        } 
+        }
         println!("{}", x);
-        
+
         let ops = DefaultOpsFactory::<f32>::make();
         let elts = tokenize_and_analyze(text, &ops, is_numeric_text);
         match elts {
@@ -416,7 +424,10 @@ fn test_preconditions() {
     );
     test("xo-17-(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((expWW-tr-3746-4+sinnex-nn--nnexpWW-tr-7492-4+4-nsqrnexq+---------282)-384", "parentheses mismatch");
     test("fi.g", "don't know how to parse .g");
-    test("(nc7)sqrtE", "wlog a number/variable cannot be on the right");
+    test(
+        "(nc7)sqrtE",
+        "wlog a number/variable cannot be on the right",
+    );
     test("", "empty string");
     test("++", "the last element cannot be an operator");
     test(
